==> resin-3.1.13-src.tar.gz: resin-3.1.13/modules/resin/src/com/caucho/server/webapp/LocaleEncodingMappingList.java <==
/*
 * Copyright (c) 1998-2008 Caucho Technology -- all rights reserved
 *
 * This file is part of Resin(R) Open Source
 *
 * Each copy or derived work must preserve the copyright notice and this
 * notice unmodified.
 *
 * Resin Open Source is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * Resin Open Source is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE, or any warranty
 * of NON-INFRINGEMENT.  See the GNU General Public License for more
 * details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Resin Open Source; if not, write to the
 *   Free SoftwareFoundation, Inc.
 *   59 Temple Place, Suite 330
 *   Boston, MA 02111-1307  USA
 *
 * @author Scott Ferguson
 */

package com.caucho.server.webapp;

import com.caucho.log.Log;
import com.caucho.util.L10N;

import javax.annotation.PostConstruct;
import java.util.logging.Logger;

/**
 * Configuration for the locale.
 */
public class LocaleEncodingMappingList {
  static final L10N L = new L10N(LocaleEncodingMappingList.class);
  static final Logger log = Log.open(LocaleEncodingMappingList.class);

  private WebApp _app;

  /**
   * Creates the webApp with its environment loader.
   */
  LocaleEncodingMappingList(WebApp app)
  {
    _app = app;
  }

  /**
   * Creates the locale encoding mapping.
   */
  public LocaleEncodingMapping createLocaleEncodingMapping()
  {
    return new LocaleEncodingMapping();
  }

  public class LocaleEncodingMapping {
    private String _locale;
    private String _encoding;

    public void setLocale(String locale)
    {
      _locale = locale;
    }

    public void setEncoding(String encoding)
    {
      _encoding = encoding;
    }

    @PostConstruct
    public void init()
    {
      _app.putLocaleEncoding(_locale, _encoding);
    }
  }
}

==> resin-4.0.52-src.tar.gz: resin-4.0.52/modules/resin/src/com/caucho/server/webapp/LocaleEncodingMappingList.java <==
/*
 * Copyright (c) 1998-2012 Caucho Technology -- all rights reserved
 *
 * This file is part of Resin(R) Open Source
 *
 * Each copy or derived work must preserve the copyright notice and this
 * notice unmodified.
 *
 * Resin Open Source is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * Resin Open Source is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE, or any warranty
 * of NON-INFRINGEMENT.  See the GNU General Public License for more
 * details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Resin Open Source; if not, write to the
 *   Free SoftwareFoundation, Inc.
 *   59 Temple Place, Suite 330
 *   Boston, MA 02111-1307  USA
 *
 * @author Scott Ferguson
 */

package com.caucho.server.webapp;

import com.caucho.util.L10N;

import javax.annotation.PostConstruct;
import java.util.logging.Logger;

/**
 * Configuration for the locale.
 */
public class LocaleEncodingMappingList {
  static final L10N L = new L10N(LocaleEncodingMappingList.class);
  static final Logger log
    = Logger.getLogger(LocaleEncodingMappingList.class.getName());

  private WebApp _app;

  /**
   * Creates the webApp with its environment loader.
   */
  LocaleEncodingMappingList(WebApp app)
  {
    _app = app;
  }

  /**
   * Creates the locale encoding mapping.
   */
  public LocaleEncodingMapping createLocaleEncodingMapping()
  {
    return new LocaleEncodingMapping();
  }

  public class LocaleEncodingMapping {
    private String _locale;
    private String _encoding;

    public void setLocale(String locale)
    {
      _locale = locale;
    }

    public void setEncoding(String encoding)
    {
      _encoding = encoding;
    }

    @PostConstruct
    public void init()
    {
      _app.putLocaleEncoding(_locale, _encoding);
    }
  }
}
